@@ -1,9 +1,8 @@
-from data_exporter import settings
+from . import settings
+from .channels import get_channel
 
 from celery.task import task, chord
 
-from data_exporter.channels import get_channel
-
 
 @task
 def inline(name, mimetype, offset, limit, *args, **kwargs):
