@@ -1,6 +1,7 @@
-from mock import patch, MagicMock
+from mock import patch
 
 import os
+import shutil
 
 from datetime import datetime
 
@@ -9,17 +10,22 @@ from django.core.exceptions import ImproperlyConfigured
 
 from data_exporter import channels, tasks, settings
 from data_exporter.base import Export
-from data_exporter.tests.exports import PollExport
 from data_exporter.tests.models import Poll
 from data_exporter.signals import export_done, combine_done
 
 
-class ChannelTests(TestCase):
-    def test_get_channel(self):
-        channel = channels.get_channel('polls')
+class BaseTests(TestCase):
+    def setUp(self):
+        self.channel = channels.get_channel('polls')
+        self.storage = self.channel.storage
 
-        self.assertTrue(isinstance(channel, PollExport))
+        try:
+            shutil.rmtree(self.storage.location)
+        except OSError:
+            pass
 
+
+class ChannelTests(BaseTests):
     def test_get_unknown_channel(self):
         self.assertRaises(ImproperlyConfigured, channels.get_channel, 'random')
 
@@ -29,10 +35,7 @@ class ChannelTests(TestCase):
         self.assertRaises(ImproperlyConfigured, channels.get_channel, 'choices')
 
 
-class ExportTests(TestCase):
-    def setUp(self):
-        self.channel = channels.get_channel('polls')
-
+class ExportTests(BaseTests):
     def test_format(self):
         obj = type('lamdbaobject', (object,), {'key': 'value'})()
 
@@ -44,7 +47,7 @@ class ExportTests(TestCase):
 
             get_formatted_date_method.return_value = date_format
 
-            self.assertEqual(self.channel.get_directory(), os.path.join(settings.DATA_EXPORTER_DIRECTORY, self.channel.directory, date_format))
+            self.assertEqual(self.channel.get_directory(), os.path.join(self.channel.directory, date_format))
 
             self.assertEqual(self.channel.get_file_root('xls'),
                              os.path.join(self.channel.get_directory(),
@@ -61,70 +64,64 @@ class ExportTests(TestCase):
         self.assertEqual(dataset.headers, list(self.channel.headers))
 
     def test_write(self):
-        with patch('__builtin__.open', create=True) as mock_open:
-            mock_open.return_value = MagicMock(spec=file)
+        data = [[1, 'test']]
 
-            data = [[1, 'test']]
+        self.channel.write(data, 'csv')
 
-            self.channel.write(data, 'csv')
+        file_root = self.channel.get_file_root('csv')
 
-            file_handle = mock_open.return_value.__enter__.return_value
-
-            file_handle.write.assert_called_with(self.channel._generate_dataset(data).csv)
+        self.assertTrue(self.storage.exists(file_root))
 
     def test_export_signals_sent(self):
-        with patch('__builtin__.open', create=True) as mock_open:
-            def callback(sender, **kwargs):
-                self.export = True
+        def callback(sender, **kwargs):
+            self.export = True
 
-            export_done.connect(callback)
+        export_done.connect(callback)
 
-            self.export = False
+        self.export = False
 
-            mock_open.return_value = MagicMock(spec=file)
+        data = [[1, 'test']]
 
-            data = [[1, 'test']]
+        self.channel.write(data, 'csv')
 
-            self.channel.write(data, 'csv')
-
-            self.assertTrue(self.export)
+        self.assertTrue(self.export)
 
     def test_combine_signals_sent(self):
-        with patch('__builtin__.open', create=True) as mock_open:
-            def callback(sender, **kwargs):
-                self.export = True
+        def callback(sender, **kwargs):
+            self.export = True
 
-            combine_done.connect(callback)
+        combine_done.connect(callback)
 
-            self.export = False
+        self.export = False
 
-            mock_open.return_value = MagicMock(spec=file)
+        tasks.inline('polls', 'csv', 0, 100)  # NOQA
 
-            self.channel.combine(((0, 100),), 'csv')
+        self.channel.combine(((0, 100),), 'csv')
 
-            self.assertTrue(self.export)
+        self.assertTrue(self.export)
 
 
-class TasksTests(TestCase):
+class TasksTests(BaseTests):
     length = 1000
 
     def setUp(self):
+        super(TasksTests, self).setUp()
+
         for i in xrange(self.length):
             Poll.objects.create(question='Fake question n.%d' % i)
 
     def test_inline_task(self):
-        with patch('__builtin__.open', create=True) as mock_open:
-            mock_open.return_value = MagicMock(spec=file)
+        tasks.inline('polls', 'csv', 0, 100)  # NOQA
 
-            tasks.inline('polls', 'csv', 0, 100)  # NOQA
+        file_root = self.channel.get_file_root('csv', 0, 100)
 
-            file_handle = mock_open.return_value.__enter__.return_value
+        file = self.storage.open(file_root)
 
-            datas = file_handle.write._mock_call_args[0][0].split('\n')
+        lines = file.readlines()
 
-            self.assertEqual(len(datas), 102)
+        self.assertEqual(len(lines), 101)
 
-            self.assertEqual(len(datas[0].split(',')), len(channels.get_channel('polls').columns))
+        self.assertEqual(len(lines[0].split(',')), len(channels.get_channel('polls').columns))
 
     def test_builder_task(self):
         self.assertEqual(len(tasks.generate_subtasks_builder('polls', 'csv', 100)), 10)
